@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem directory name',
@@ -58,7 +58,7 @@ Sah::Schema::dirname - Filesystem directory name
 
 =head1 VERSION
 
-This document describes version 0.029 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+This document describes version 0.030 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
 
 =head1 SAH SCHEMA DEFINITION
 
@@ -79,7 +79,7 @@ Base type: L<str|Data::Sah::Type::str>
 
 Used prefilters: L<Path::expand_tilde_when_on_unix|Data::Sah::Filter::perl::Path::expand_tilde_when_on_unix>, L<Path::strip_slashes_when_on_unix|Data::Sah::Filter::perl::Path::strip_slashes_when_on_unix>
 
-Used completion: L<dirname|Perinci::Sub::XComplete::dirname>
+Used completion: L<dirname|Perinci::Sub::XCompletion::dirname>
 
 =head1 SYNOPSIS
 
