@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem path name on a Unix system',
@@ -49,7 +49,7 @@ Sah::Schema::pathname::unix - Filesystem path name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.029 of Sah::Schema::pathname::unix (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+This document describes version 0.030 of Sah::Schema::pathname::unix (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
 
 =head1 SAH SCHEMA DEFINITION
 
@@ -67,7 +67,7 @@ Base type: L<str|Data::Sah::Type::str>
 
 Used prefilters: L<Path::expand_tilde|Data::Sah::Filter::perl::Path::expand_tilde>, L<Path::strip_slashes|Data::Sah::Filter::perl::Path::strip_slashes>
 
-Used completion: L<filename|Perinci::Sub::XComplete::filename>
+Used completion: L<filename|Perinci::Sub::XCompletion::filename>
 
 =head1 SYNOPSIS
 
